[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Real-Time Price Alerting client library for Python

[![API Version](https://img.shields.io/badge/api-v3.0.0-blue)](https://developer.factset.com/api-catalog/)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.RealTimePriceAlerting/0.12.1)](https://pypi.org/project/fds.sdk.RealTimePriceAlerting/v/0.12.1)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

The Price Alerting API is designed to inform the users of an application directly about important changes in the data on the platform.
The endpoint group *basic price alerting* deals with generation of alerts based on current price data. For notations, users can define
an upper or lower limit and choose on which price type those limit conditions apply.

Alerting uses the concepts of triggers and alerts. 

* A trigger is an entity that is set up by an application to watch a certain condition in the market data around a financial instrument.
  The standard conditions that can be applied are lower limit and upper limit for the value of the price for a given financial instrument.
* When the condition of a trigger is met, an alert is created. Each alert thus represents one event where a trigger condition was met.

An application can learn about the creation of alerts in two ways: The application can actively request the list of alerts (pull approach)
or it can subscribe to the list of existing alerts. If a new alert is created, that list changes and the application is notified about
the new alert with an update that contains the details on the new alert (push approach).

The API supports both approaches. The push approach is realized most easily by using the subscription support that the client libraries provide.

See the [Real-Time Quotes API](https://developer.factset.com/api-catalog/real-time-quotes-api) for access to detailed price information.

Note: As part of the general trial access, endpoints to write data are excluded. For a description of the full alerting API, please work with a
FactSet consultant and see https://endpointreference.factset.com.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.0.0
- SDK version: 0.12.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.RealTimePriceAlerting==0.12.1
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.RealTimePriceAlerting==0.12.1
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.RealTimePriceAlerting
from fds.sdk.RealTimePriceAlerting.api import alerting_api
from fds.sdk.RealTimePriceAlerting.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.RealTimePriceAlerting.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.RealTimePriceAlerting.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.RealTimePriceAlerting.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = alerting_api.AlertingApi(api_client)
    id = "4004" # str | Identifier of the alert.
    attributes = [
        "_attributes_example",
    ] # [str] | Limit the attributes returned in the response to the specified set. (optional)

    try:
        # Details of an alert.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_alerting_prices_basic_alert_get(id, attributes=attributes)

        pprint(api_response)
    except fds.sdk.RealTimePriceAlerting.ApiException as e:
        print("Exception when calling AlertingApi->get_alerting_prices_basic_alert_get: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Details of an alert.
    #     api_response, http_status_code, response_headers = api_instance.get_alerting_prices_basic_alert_get_with_http_info(id, attributes=attributes)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimePriceAlerting.ApiException as e:
    #     print("Exception when calling AlertingApi->get_alerting_prices_basic_alert_get: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Details of an alert.
    #     async_result = api_instance.get_alerting_prices_basic_alert_get_async(id, attributes=attributes)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.RealTimePriceAlerting.ApiException as e:
    #     print("Exception when calling AlertingApi->get_alerting_prices_basic_alert_get: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Details of an alert.
    #     async_result = api_instance.get_alerting_prices_basic_alert_get_with_http_info_async(id, attributes=attributes)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimePriceAlerting.ApiException as e:
    #     print("Exception when calling AlertingApi->get_alerting_prices_basic_alert_get: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.RealTimePriceAlerting

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.RealTimePriceAlerting.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.RealTimePriceAlerting

configuration = fds.sdk.RealTimePriceAlerting.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.RealTimePriceAlerting

configuration = fds.sdk.RealTimePriceAlerting.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.RealTimePriceAlerting

configuration = fds.sdk.RealTimePriceAlerting.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AlertingApi* | [**get_alerting_prices_basic_alert_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/AlertingApi.md#get_alerting_prices_basic_alert_get) | **GET** /alerting/prices/basic/alert/get | Details of an alert.
*AlertingApi* | [**get_alerting_prices_basic_alert_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/AlertingApi.md#get_alerting_prices_basic_alert_list) | **GET** /alerting/prices/basic/alert/list | List of alerts.
*AlertingApi* | [**get_alerting_prices_basic_trigger_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/AlertingApi.md#get_alerting_prices_basic_trigger_get) | **GET** /alerting/prices/basic/trigger/get | Details of a trigger.
*AlertingApi* | [**post_alerting_prices_basic_trigger_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/AlertingApi.md#post_alerting_prices_basic_trigger_list) | **POST** /alerting/prices/basic/trigger/list | List of triggers.


## Documentation For Models

 - [AttributesMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/AttributesMember.md)
 - [CursorBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/CursorBasedPaginationOutputObject.md)
 - [GetAlertingPricesBasicAlertGetDataNotificationStatusItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertGetDataNotificationStatusItems.md)
 - [GetAlertingPricesBasicAlertGetDataNotificationStatusItemsChannel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertGetDataNotificationStatusItemsChannel.md)
 - [GetAlertingPricesBasicAlertListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItems.md)
 - [GetAlertingPricesBasicAlertListDataItemsNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsNotification.md)
 - [GetAlertingPricesBasicAlertListDataItemsTrigger](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsTrigger.md)
 - [GetAlertingPricesBasicAlertListDataItemsTriggerNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsTriggerNotification.md)
 - [GetAlertingPricesBasicAlertListDataItemsTriggerNotificationChannel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsTriggerNotificationChannel.md)
 - [GetAlertingPricesBasicAlertListDataItemsTriggerPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsTriggerPrice.md)
 - [GetAlertingPricesBasicAlertListDataItemsTriggerRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataItemsTriggerRange.md)
 - [GetAlertingPricesBasicAlertListDataNotificationStatusItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataNotificationStatusItems.md)
 - [GetAlertingPricesBasicAlertListDataNotificationStatusItemsChannel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicAlertListDataNotificationStatusItemsChannel.md)
 - [GetAlertingPricesBasicTriggerGetDataNotificationChannelItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/GetAlertingPricesBasicTriggerGetDataNotificationChannelItems.md)
 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200.md)
 - [InlineResponse2001](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2001.md)
 - [InlineResponse2001Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2001Meta.md)
 - [InlineResponse2002](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002.md)
 - [InlineResponse2002Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002Data.md)
 - [InlineResponse2002DataNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002DataNotification.md)
 - [InlineResponse2002DataPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002DataPrice.md)
 - [InlineResponse2002DataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002DataRange.md)
 - [InlineResponse2002DataStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2002DataStatus.md)
 - [InlineResponse2003](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse2003.md)
 - [InlineResponse200Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200Data.md)
 - [InlineResponse200DataNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataNotification.md)
 - [InlineResponse200DataPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataPrice.md)
 - [InlineResponse200DataTrigger](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTrigger.md)
 - [InlineResponse200DataTriggerNotation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerNotation.md)
 - [InlineResponse200DataTriggerNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerNotification.md)
 - [InlineResponse200DataTriggerNotificationChannel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerNotificationChannel.md)
 - [InlineResponse200DataTriggerPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerPrice.md)
 - [InlineResponse200DataTriggerRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerRange.md)
 - [InlineResponse200DataTriggerStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200DataTriggerStatus.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/InlineResponse200Meta.md)
 - [PostAlertingPricesBasicTriggerListDataItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataItems.md)
 - [PostAlertingPricesBasicTriggerListDataItemsNotification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataItemsNotification.md)
 - [PostAlertingPricesBasicTriggerListDataItemsPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataItemsPrice.md)
 - [PostAlertingPricesBasicTriggerListDataItemsRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataItemsRange.md)
 - [PostAlertingPricesBasicTriggerListDataItemsStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataItemsStatus.md)
 - [PostAlertingPricesBasicTriggerListDataNotificationChannelItems](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListDataNotificationChannelItems.md)
 - [PostAlertingPricesBasicTriggerListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequest.md)
 - [PostAlertingPricesBasicTriggerListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequestData.md)
 - [PostAlertingPricesBasicTriggerListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequestDataFilter.md)
 - [PostAlertingPricesBasicTriggerListRequestDataFilterStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequestDataFilterStatus.md)
 - [PostAlertingPricesBasicTriggerListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequestMeta.md)
 - [PostAlertingPricesBasicTriggerListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/PostAlertingPricesBasicTriggerListRequestMetaPagination.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimePriceAlerting/v3/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.RealTimePriceAlerting.apis and fds.sdk.RealTimePriceAlerting.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.RealTimePriceAlerting.api.default_api import DefaultApi`
- `from fds.sdk.RealTimePriceAlerting.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.RealTimePriceAlerting
from fds.sdk.RealTimePriceAlerting.apis import *
from fds.sdk.RealTimePriceAlerting.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

